@@ -13,7 +13,12 @@
 # permissions and limitations under the License.
 from .Namespace import Namespace
 from .options.NamespaceOptions import NamespaceOptions
+from .TakeOverTypeModel import TakeOverTypeModel
+from .options.TakeOverTypeModelOptions import TakeOverTypeModelOptions
+from .OpenIdConnectSetting import OpenIdConnectSetting
+from .options.OpenIdConnectSettingOptions import OpenIdConnectSettingOptions
 from .PlatformUser import PlatformUser
 from .options.PlatformUserOptions import PlatformUserOptions
 from .BanStatus import BanStatus
-from .options.BanStatusOptions import BanStatusOptions
\ No newline at end of file
+from .options.BanStatusOptions import BanStatusOptions
+from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
