@@ -16,4 +16,6 @@ from .options.NamespaceOptions import NamespaceOptions
 from .AdMob import AdMob
 from .options.AdMobOptions import AdMobOptions
 from .UnityAd import UnityAd
-from .options.UnityAdOptions import UnityAdOptions
\ No newline at end of file
+from .options.UnityAdOptions import UnityAdOptions
+from .AppLovinMax import AppLovinMax
+from .options.AppLovinMaxOptions import AppLovinMaxOptions
\ No newline at end of file
