@@ -22,4 +22,12 @@ from .options.AcquireActionRateOptions import AcquireActionRateOptions
 from .enum.AcquireActionRateMode import AcquireActionRateMode
 from .options.AcquireActionRateModeIsDoubleOptions import AcquireActionRateModeIsDoubleOptions
 from .options.AcquireActionRateModeIsBigOptions import AcquireActionRateModeIsBigOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
