@@ -19,6 +19,7 @@ from .options.ReceiveMemberRequestOptions import ReceiveMemberRequestOptions
 class ReceiveMemberRequest:
     user_id: str
     target_guild_name: str
+    metadata: Optional[str] = None
 
     def __init__(
         self,
@@ -28,6 +29,7 @@ class ReceiveMemberRequest:
     ):
         self.user_id = user_id
         self.target_guild_name = target_guild_name
+        self.metadata = options.metadata if options.metadata else None
 
     def properties(
         self,
@@ -38,5 +40,7 @@ class ReceiveMemberRequest:
             properties["userId"] = self.user_id
         if self.target_guild_name is not None:
             properties["targetGuildName"] = self.target_guild_name
+        if self.metadata is not None:
+            properties["metadata"] = self.metadata
 
         return properties
