@@ -15,4 +15,8 @@ from .NamespaceRef import NamespaceRef
 from .GuildModelRef import GuildModelRef
 from .InboxRef import InboxRef
 from .GuildRef import GuildRef
-from .RoleModelRef import RoleModelRef
\ No newline at end of file
+from .IgnoreUsersRef import IgnoreUsersRef
+from .LastGuildMasterActivityRef import LastGuildMasterActivityRef
+from .MasterDataVersionRef import MasterDataVersionRef
+from .RoleModelRef import RoleModelRef
+from .IgnoreUserRef import IgnoreUserRef
\ No newline at end of file
