@@ -35,4 +35,6 @@ from .ExecuteStampTaskLogCount import ExecuteStampTaskLogCount
 from .options.ExecuteStampTaskLogCountOptions import ExecuteStampTaskLogCountOptions
 from .AccessLogWithTelemetry import AccessLogWithTelemetry
 from .options.AccessLogWithTelemetryOptions import AccessLogWithTelemetryOptions
-from .enum.AccessLogWithTelemetryStatus import AccessLogWithTelemetryStatus
\ No newline at end of file
+from .enum.AccessLogWithTelemetryStatus import AccessLogWithTelemetryStatus
+from .InGameLogTag import InGameLogTag
+from .options.InGameLogTagOptions import InGameLogTagOptions
\ No newline at end of file
