@@ -13,8 +13,11 @@
 # permissions and limitations under the License.
 from .CounterScopeModel import CounterScopeModel
 from .options.CounterScopeModelOptions import CounterScopeModelOptions
+from .enum.CounterScopeModelScopeType import CounterScopeModelScopeType
 from .enum.CounterScopeModelResetType import CounterScopeModelResetType
 from .enum.CounterScopeModelResetDayOfWeek import CounterScopeModelResetDayOfWeek
+from .options.CounterScopeModelScopeTypeIsResetTimingOptions import CounterScopeModelScopeTypeIsResetTimingOptions
+from .options.CounterScopeModelScopeTypeIsVerifyActionOptions import CounterScopeModelScopeTypeIsVerifyActionOptions
 from .options.CounterScopeModelResetTypeIsNotResetOptions import CounterScopeModelResetTypeIsNotResetOptions
 from .options.CounterScopeModelResetTypeIsDailyOptions import CounterScopeModelResetTypeIsDailyOptions
 from .options.CounterScopeModelResetTypeIsWeeklyOptions import CounterScopeModelResetTypeIsWeeklyOptions
@@ -36,11 +39,25 @@ from .options.MissionTaskModelOptions import MissionTaskModelOptions
 from .enum.MissionTaskModelVerifyCompleteType import MissionTaskModelVerifyCompleteType
 from .enum.MissionTaskModelTargetResetType import MissionTaskModelTargetResetType
 from .options.MissionTaskModelVerifyCompleteTypeIsCounterOptions import MissionTaskModelVerifyCompleteTypeIsCounterOptions
-from .options.MissionTaskModelVerifyCompleteTypeIsConsumeActionsOptions import MissionTaskModelVerifyCompleteTypeIsConsumeActionsOptions
+from .options.MissionTaskModelVerifyCompleteTypeIsVerifyActionsOptions import MissionTaskModelVerifyCompleteTypeIsVerifyActionsOptions
 from .ScopedValue import ScopedValue
 from .options.ScopedValueOptions import ScopedValueOptions
+from .enum.ScopedValueScopeType import ScopedValueScopeType
 from .enum.ScopedValueResetType import ScopedValueResetType
+from .options.ScopedValueScopeTypeIsResetTimingOptions import ScopedValueScopeTypeIsResetTimingOptions
+from .options.ScopedValueScopeTypeIsVerifyActionOptions import ScopedValueScopeTypeIsVerifyActionOptions
 from .TargetCounterModel import TargetCounterModel
 from .options.TargetCounterModelOptions import TargetCounterModelOptions
+from .enum.TargetCounterModelScopeType import TargetCounterModelScopeType
 from .enum.TargetCounterModelResetType import TargetCounterModelResetType
+from .options.TargetCounterModelScopeTypeIsResetTimingOptions import TargetCounterModelScopeTypeIsResetTimingOptions
+from .options.TargetCounterModelScopeTypeIsVerifyActionOptions import TargetCounterModelScopeTypeIsVerifyActionOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
