@@ -16,10 +16,12 @@ from .options.NamespaceOptions import NamespaceOptions
 from .GlobalRankingModel import GlobalRankingModel
 from .options.GlobalRankingModelOptions import GlobalRankingModelOptions
 from .enum.GlobalRankingModelOrderDirection import GlobalRankingModelOrderDirection
+from .enum.GlobalRankingModelRewardCalculationIndex import GlobalRankingModelRewardCalculationIndex
 from .ClusterRankingModel import ClusterRankingModel
 from .options.ClusterRankingModelOptions import ClusterRankingModelOptions
 from .enum.ClusterRankingModelClusterType import ClusterRankingModelClusterType
 from .enum.ClusterRankingModelOrderDirection import ClusterRankingModelOrderDirection
+from .enum.ClusterRankingModelRewardCalculationIndex import ClusterRankingModelRewardCalculationIndex
 from .SubscribeRankingModel import SubscribeRankingModel
 from .options.SubscribeRankingModelOptions import SubscribeRankingModelOptions
 from .enum.SubscribeRankingModelOrderDirection import SubscribeRankingModelOrderDirection
