@@ -25,6 +25,16 @@ from .options.EventRepeatTypeIsAlwaysOptions import EventRepeatTypeIsAlwaysOptio
 from .options.EventRepeatTypeIsDailyOptions import EventRepeatTypeIsDailyOptions
 from .options.EventRepeatTypeIsWeeklyOptions import EventRepeatTypeIsWeeklyOptions
 from .options.EventRepeatTypeIsMonthlyOptions import EventRepeatTypeIsMonthlyOptions
+from .RepeatSetting import RepeatSetting
+from .options.RepeatSettingOptions import RepeatSettingOptions
+from .enum.RepeatSettingRepeatType import RepeatSettingRepeatType
+from .enum.RepeatSettingBeginDayOfWeek import RepeatSettingBeginDayOfWeek
+from .enum.RepeatSettingEndDayOfWeek import RepeatSettingEndDayOfWeek
+from .options.RepeatSettingRepeatTypeIsAlwaysOptions import RepeatSettingRepeatTypeIsAlwaysOptions
+from .options.RepeatSettingRepeatTypeIsDailyOptions import RepeatSettingRepeatTypeIsDailyOptions
+from .options.RepeatSettingRepeatTypeIsWeeklyOptions import RepeatSettingRepeatTypeIsWeeklyOptions
+from .options.RepeatSettingRepeatTypeIsMonthlyOptions import RepeatSettingRepeatTypeIsMonthlyOptions
+from .options.RepeatSettingRepeatTypeIsCustomOptions import RepeatSettingRepeatTypeIsCustomOptions
 from .RepeatSchedule import RepeatSchedule
 from .options.RepeatScheduleOptions import RepeatScheduleOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
