@@ -19,6 +19,14 @@ from .SeasonModel import SeasonModel
 from .options.SeasonModelOptions import SeasonModelOptions
 from .TierModel import TierModel
 from .options.TierModelOptions import TierModelOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .GameResult import GameResult
 from .options.GameResultOptions import GameResultOptions
 from .SignedBallot import SignedBallot
